package test.service;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.After;
import org.junit.Test;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;

import dao.TeacherDAO;
import dao.impl.TeacherDAOImpl;
import model.Teacher;
import service.TeacherService;
import service.ServiceFactory;
import util.DatabaseUtil;

public class TeacherServiceTest {
    
    private TeacherService teacherService;
    private TeacherDAO teacherDAO;
    private static final String TEST_TEACHER_ID = "T2024001";
    
    @Before
    public void setUp() throws SQLException {
        teacherService = ServiceFactory.getTeacherService();
        teacherDAO = new TeacherDAOImpl();
        // 清理测试数据
        cleanTestData();
        // 准备测试数据
        Teacher teacher = createTestTeacher();
        teacherDAO.insert(teacher);
    }
    
    @After
    public void tearDown() throws SQLException {
        cleanTestData();
    }
    
    private void cleanTestData() throws SQLException {
        try (Connection conn = DatabaseUtil.getConnection();
             PreparedStatement stmt = conn.prepareStatement("DELETE FROM teachers WHERE teacher_id = ?")) {
            stmt.setString(1, TEST_TEACHER_ID);
            stmt.executeUpdate();
        }
    }
    
    private Teacher createTestTeacher() {
        Teacher teacher = new Teacher();
        teacher.setTeacherId(TEST_TEACHER_ID);
        teacher.setName("测试教师");
        teacher.setDepartment("计算机系");
        teacher.setContact("13800138000");
        teacher.setPassword("password123");
        return teacher;
    }
    
    @Test
    public void testLoginSuccess() {
        Teacher teacher = teacherService.login(TEST_TEACHER_ID, "password123");
        assertNotNull("使用正确的工号和密码应该登录成功", teacher);
        assertEquals("登录后返回的教师工号应该匹配", TEST_TEACHER_ID, teacher.getTeacherId());
        assertEquals("登录后返回的教师姓名应该匹配", "测试教师", teacher.getName());
    }
    
    @Test
    public void testLoginFailure() {
        Teacher teacher = teacherService.login(TEST_TEACHER_ID, "wrongPassword");
        assertNull("使用错误的密码应该登录失败", teacher);
    }
    
    @Test
    public void testLoginWithNonexistentUser() {
        Teacher teacher = teacherService.login("nonexistent", "password123");
        assertNull("使用不存在的工号应该登录失败", teacher);
    }
}
